@@ -18,7 +18,6 @@ from .exceptions import TigoAPIError
 load_dotenv()
 
 
-
 class TigoClient:
     """
     Clean API wrapper for Tigo Energy platform.
@@ -43,8 +42,6 @@ class TigoClient:
     MAX_PANELS_TO_ANALYZE = 10
     PANEL_VARIATION_RANGE = (0.85, 1.15)  # 85% to 115% variation
 
-
-
     def __init__(self, username: Optional[str] = None, password: Optional[str] = None):
         """
         Initialize TigoClient.
@@ -72,7 +69,6 @@ class TigoClient:
             headers=self.authenticator.get_headers(),
             timeout=self.DEFAULT_TIMEOUT 
         )
-        
 
     def __enter__(self):
         return self
@@ -100,6 +96,25 @@ class TigoClient:
             raise TigoAPIError(None, f"Unexpected error: {e}")
 
 
+    def _ensure_client_open(self):
+        """Ensure the HTTP client is open, recreate if needed."""
+        if not hasattr(self, 'client') or self.client.is_closed:
+            self.client = httpx.Client(
+                base_url=self.BASE_URL, 
+                headers=self.authenticator.get_headers(),
+                timeout=self.DEFAULT_TIMEOUT 
+            )
+
+    def _make_request(self, method: str, endpoint: str, **kwargs) -> httpx.Response:
+        """Make HTTP request with error handling."""
+        self._ensure_client_open()  # Ensure client is open before each request
+        response = getattr(self.client, method.lower())(endpoint, **kwargs)
+        
+        if response.status_code != 200:
+            raise TigoAPIError(response)
+        return response
+
+
     def get(self, endpoint: str, **kwargs) -> Dict[str, Any]:
         """Make GET request and return JSON."""
         response = self._make_request('GET', endpoint, **kwargs)
@@ -168,17 +183,6 @@ class TigoClient:
         """Get system summary data."""
         return self.get("/data/summary", params={"system_id": system_id})
 
-    # Keep backward compatibility with deprecated methods
-    def get_aggregate_data_raw(self, *args, **kwargs) -> str:
-        """Deprecated: Use get_aggregate_data(return_dataframe=False) instead."""
-        self.logger.warning("get_aggregate_data_raw is deprecated, use get_aggregate_data(return_dataframe=False)")
-        return self.get_aggregate_data(*args, return_dataframe=False, **kwargs)
-
-    def get_combined_data_raw(self, *args, **kwargs) -> str:
-        """Deprecated: Use get_combined_data(return_dataframe=False) instead."""
-        self.logger.warning("get_combined_data_raw is deprecated, use get_combined_data(return_dataframe=False)")
-        return self.get_combined_data(*args, return_dataframe=False, **kwargs)    
-
     # Alert endpoints
     def get_alerts(
         self, 
@@ -279,6 +283,16 @@ class TigoClient:
         csv_data = self.get_raw("/data/combined", params=params)
         return self.csv_to_dataframe(csv_data) if return_dataframe else csv_data
 
+    # Keep backward compatibility with deprecated methods
+    def get_aggregate_data_raw(self, *args, **kwargs) -> str:
+        """Deprecated: Use get_aggregate_data(return_dataframe=False) instead."""
+        self.logger.warning("get_aggregate_data_raw is deprecated, use get_aggregate_data(return_dataframe=False)")
+        return self.get_aggregate_data(*args, return_dataframe=False, **kwargs)
+
+    def get_combined_data_raw(self, *args, **kwargs) -> str:
+        """Deprecated: Use get_combined_data(return_dataframe=False) instead."""
+        self.logger.warning("get_combined_data_raw is deprecated, use get_combined_data(return_dataframe=False)")
+        return self.get_combined_data(*args, return_dataframe=False, **kwargs)
 
     # --------------------
     # Enhanced Analysis Methods
@@ -308,7 +322,7 @@ class TigoClient:
             start, end = self.get_safe_date_range(days_back, level)
             return self.get_combined_data(system_id, start, end, level=level)
         except Exception as e:
-            self.logger.warning(f"Could not get today's data: {e}")
+            self.logger.warning(f"Could not get date range data: {e}")
             return pd.DataFrame()
 
     def calculate_system_efficiency(
@@ -625,7 +639,6 @@ class TigoClient:
         """
         end = datetime.now()
         
-        
         if level == "minute":
             # For minute-level data, enforce the strict limit
             requested_minutes = days_back * 24 * 60
